<?php
/**
 * Business Accounting functions and definitions
 *
 * @subpackage Business Accounting
 * @since 1.0
 */

include get_theme_file_path( 'vendor/wptrt/autoload/src/Business_Accounting_Loader.php' );

$business_accounting_loader = new \WPTRT\Autoload\Business_Accounting_Loader();

$business_accounting_loader->business_accounting_add( 'WPTRT\\Customize\\Section', get_theme_file_path( 'vendor/wptrt/customize-section-button/src' ) );

$business_accounting_loader->business_accounting_register();

function business_accounting_setup() {	

	load_theme_textdomain( 'business-accounting', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'responsive-embeds' );
	add_theme_support( 'html5', array( 'comment-list', 'search-form', 'comment-form', ) );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-background', $defaults = array(
	    'default-color'          => '',
	    'default-image'          => '',
	    'default-repeat'         => '',
	    'default-position-x'     => '',
	    'default-attachment'     => '',
	    'wp-head-callback'       => '_custom_background_cb',
	    'admin-head-callback'    => '',
	    'admin-preview-callback' => ''
	));

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'business-accounting' ),
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style( array( 'assets/css/editor-style.css', business_accounting_fonts_url() ) );

	// Theme Activation Notice
	global $pagenow;

		if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
		add_action( 'admin_notices', 'business_accounting_activation_notice' );
	}

}
add_action( 'after_setup_theme', 'business_accounting_setup' );

// Notice after Theme Activation
function business_accounting_activation_notice() {
	echo '<div class="notice notice-success is-dismissible start-notice">';
		echo '<h3>'. esc_html__( 'Welcome to Luzuk!!', 'business-accounting' ) .'</h3>';
		echo '<p>'. esc_html__( 'Thank you for choosing Business Accounting theme. It will be our pleasure to have you on our Welcome page to serve you better.', 'business-accounting' ) .'</p>';
		echo '<p><a href="'. esc_url( admin_url( 'themes.php?page=business_accounting_guide' ) ) .'" class="button button-primary">'. esc_html__( 'GET STARTED', 'business-accounting' ) .'</a></p>';
	echo '</div>';
}

function business_accounting_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'business-accounting' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'business-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h2 class="widget-title">',
		'after_title'   => '</h2></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 2', 'business-accounting' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'business-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h2 class="widget-title">',
		'after_title'   => '</h2></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'business-accounting' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'business-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h2 class="widget-title">',
		'after_title'   => '</h2></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'business-accounting' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'business-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'business-accounting' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'business-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'business-accounting' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'business-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'business-accounting' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'business-accounting' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'business_accounting_widgets_init' );

function business_accounting_fonts_url(){
	$font_url = '';
	$font_family = array();
	$font_family[] = 'Work Sans:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';

	$query_args = array(
		'family'	=> rawurlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}

//Enqueue scripts and styles.
function business_accounting_scripts() {
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'business-accounting-fonts', business_accounting_fonts_url(), array(), null );
	
	//Bootstarp 
	wp_enqueue_style( 'bootstrap-css', esc_url( get_template_directory_uri() ).'/assets/css/bootstrap.css' );
	
	// Theme stylesheet.
	wp_enqueue_style( 'business-accounting-basic-style', get_stylesheet_uri() );

	// Load the Internet Explorer 9 specific stylesheet, to fix display issues in the Customizer.
	if ( is_customize_preview() ) {
		wp_enqueue_style( 'business-accounting-ie9', get_theme_file_uri( '/assets/css/ie9.css' ), array( 'business-accounting-style' ), '1.0' );
		wp_style_add_data( 'business-accounting-ie9', 'conditional', 'IE 9' );
	}
	// Load the Internet Explorer 8 specific stylesheet.
	wp_enqueue_style( 'business-accounting-ie8', get_theme_file_uri( '/assets/css/ie8.css' ), array( 'business-accounting-style' ), '1.0' );
	wp_style_add_data( 'business-accounting-ie8', 'conditional', 'lt IE 9' );

	//font-awesome
	wp_enqueue_style( 'font-awesome-css', esc_url( get_template_directory_uri() ).'/assets/css/fontawesome-all.css' );

	require get_parent_theme_file_path( '/lz-custom-style.php' );
	wp_add_inline_style( 'business-accounting-basic-style',$business_accounting_custom_style );

	$custom_css = '';

	$business_accounting_logo_top_padding = get_theme_mod('business_accounting_logo_top_padding');
	$business_accounting_logo_bottom_padding = get_theme_mod('business_accounting_logo_bottom_padding');
	$business_accounting_logo_left_padding = get_theme_mod('business_accounting_logo_left_padding');
	$business_accounting_logo_right_padding = get_theme_mod('business_accounting_logo_right_padding');

	$business_accounting_feature_section_padding = get_theme_mod('business_accounting_feature_section_padding');

	$custom_css = '
		.logo {
			padding-top: '.esc_attr($business_accounting_logo_top_padding).'px !important;
			padding-bottom: '.esc_attr($business_accounting_logo_bottom_padding).'px !important;
			padding-left: '.esc_attr($business_accounting_logo_left_padding).'px !important;
			padding-right: '.esc_attr($business_accounting_logo_right_padding).'px !important;
		}
		#our-features {
			padding-top: '.esc_attr($business_accounting_feature_section_padding).'px !important;
			padding-bottom: '.esc_attr($business_accounting_feature_section_padding).'px !important;
		}
	';
	wp_add_inline_style( 'business-accounting-basic-style',$custom_css );

	wp_enqueue_script( 'business-accounting-navigation-jquery', get_theme_file_uri( '/assets/js/navigation.js' ), array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'bootstrap-js', esc_url( get_template_directory_uri() ). '/assets/js/bootstrap.js', array('jquery') );
	wp_enqueue_script( 'jquery-superfish', esc_url( get_template_directory_uri() ). '/assets/js/jquery.superfish.js', array('jquery') ,'',true);

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'business_accounting_scripts' );

function business_accounting_front_page_template( $template ) {
	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'business_accounting_front_page_template' );

define('BUSINESS_ACCOUNTING_LIVE_DEMO',__('http://www.luzukdemo.com/demo/business-accounting/','business-accounting'));
define('BUSINESS_ACCOUNTING_PRO_DOCS',__('http://www.luzukdemo.com/docs/business-accounting/','business-accounting'));
define('BUSINESS_ACCOUNTING_BUY_NOW',__('https://www.luzuk.com/product/accounting-wordpress-theme/','business-accounting'));
define('BUSINESS_ACCOUNTING_SUPPORT',__('https://wordpress.org/support/theme/business-accounting/','business-accounting'));
define('BUSINESS_ACCOUNTING_CREDIT',__('https://www.luzuk.com/themes/free-accounting-wordpress-theme/','business-accounting'));

if ( ! function_exists( 'business_accounting_credit' ) ) {
	function business_accounting_credit(){
		echo "<a href=".esc_url(BUSINESS_ACCOUNTING_CREDIT)." target='_blank' >".esc_html__('Accounting WordPress Theme','business-accounting')."</a>";
	}
}

function business_accounting_sanitize_dropdown_pages( $page_id, $setting ) {
	// Ensure $input is an absolute integer.
	$page_id = absint( $page_id );
	// If $page_id is an ID of a published page, return it; otherwise, return the default.
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

function business_accounting_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function business_accounting_sanitize_checkbox( $input ) {
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

function business_accounting_sanitize_phone_number( $phone ) {
	return preg_replace( '/[^\d+]/', '', $phone );
}

function business_accounting_sanitize_float( $input ) {
    return filter_var($input, FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION);
}

/* Excerpt Limit Begin */
function business_accounting_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'business_accounting_loop_columns');
	if (!function_exists('business_accounting_loop_columns')) {
		function business_accounting_loop_columns() {
	return 3; // 3 products per row
	}
}

/* Breadcrumb Begin */
function fitness_club_gym_breadcrumb() {
	if (!is_home()) {
		echo '<a href="';
			echo esc_url(home_url());
		echo '">';
			bloginfo('name');
		echo "</a> ";
		if (is_category() || is_single()) {
			echo "&nbsp;>&nbsp;";
			the_category(', ');
			if (is_single()) {
				echo "&nbsp;>&nbsp;";
				echo "<span> ";
					the_title();
				echo "</span>";
			}
		} elseif (is_page()) {
			echo "&nbsp;>&nbsp;";
			echo "<span>";
				the_title();
			echo "</span> ";
		}
	}
}

require get_parent_theme_file_path( '/inc/custom-header.php' );

require get_parent_theme_file_path( '/inc/template-tags.php' );

require get_parent_theme_file_path( '/inc/template-functions.php' );

require get_parent_theme_file_path( '/inc/customizer.php' );

require get_parent_theme_file_path( '/inc/getting-started/getting-started.php' );